
// Copyright (c) 2003 Sonic Foundry, Inc. and Sonic Foundry 
// Media Systems, Inc. Neither this code nor any portion 
// thereof maybe reproduced, altered,or otherwise changed, 
// distributed or copied,without the express written 
// permission of Sonic Foundry. 
// All rights reserved.

CloseCaptioningArea.prototype = new AreaBase();
function CloseCaptioningArea(container, containingArea, ID)
{
//	this.m_debugLevel = SfDebug.Verbose;
	this.m_debugLevel = SfDebug.Information;
	this.NextCheckInterval = 1000;
	this.CaptioningFrameLoader = null;
	this.MockTimer = null;
	
	// public
	this.StartTimestamp = 0;
	this.EndTimestamp = 0;


	this.InitializeArea(container, containingArea, ID);

	this.OnLoad = function()
	{
		this.Debug("OnLoad()");		

		this.AddEventHandlers();
		
		this.MockTimer = new MockTimer(this.Container + ".MockTimer");
		this.MockTimer.Start();
		
		this.GotoServer();
	}
	
	this.OnUnLoad = function()
	{
		this.Debug("OnUnLoad()");
		this.RemoveEventHandlers();
		this.MockTimer.Stop();
	}
	
	this.AddEventHandlers = function()
	{
		this.Debug("AddEventHandlers()");
		this.ScriptEventHandler = new SfEventHandler("CloseCaptioningArea");
		this.ScriptEventHandler.MethodName = "OnScriptEvent";
		this.ScriptEventHandler.Container = this.Container;
		
		MainHelper.EventScript.AddHandler(this.ScriptEventHandler);
	}
	
	this.RemoveEventHandlers = function()
	{
		this.Debug("RemoveEventHandlers()");
		MainHelper.EventScript.RemoveHandler(this.ScriptEventHandler);
	}
	
	this.OnScriptEvent = function(args)
	{
		this.Debug("OnScriptEvent(), type: " + args.Command);
		switch(args.Command)
		{
			case SfScriptCommandType.EndPresentation:
				this.NextCheckInterval = -1;
				break;
		}
	
	}
	
	this.GotoServer = function()
	{
		this.Debug("GotoServer()");
		var url =
			Util.GetDocumentBase() + 
			"/Captioning/Gencc.aspx?" + 
			SfRequestVariables.PresentationID + "=" + MainHelper.Presentation.PresentationID +
			"&sts=" + this.StartTimestamp +
			"&ets=" + this.EndTimestamp +
			"&ct=" + this.GetCurrentTime();
		this.Debug("url: " + url);
		this.CaptioningFrameLoader = new FrameLoader(url);
		this.CaptioningFrameLoader.Load();
	}
	
	this.SetMessage = function(message)
	{
		this.Debug("Setting value: " + message);
		this.GetDiv().innerText = message;
		
		if (this.NextCheckInterval != -1)
		{
			setTimeout(this.Container + ".GotoServer()", this.NextCheckInterval);
		}
	}
	
	this.GetCurrentTime = function()
	{
		return this.MockTimer.CurrentTime;
	}
	
	this.Debug = function(msg)
	{
		SfDebug.DPF(this.m_debugLevel, "CloseCaptioningArea: " + msg);
	}
}

function MockTimer(container)
{
//	this.m_debugLevel = SfDebug.Information;
	this.m_debugLevel = SfDebug.Verbose;

	this.Container = container;
	this.UpdateInterval = 500;
	this.TimerObject = null;
	
	this.Start = function()
	{
		this.Debug("Start()");
//		this.CurrentTime = 0;
		this.CurrentTime = 22000;

		var args = new CommandArgs(SfCommandType.NavigateToSlide);
		args.SlideNumber = 4;
		MainHelper.EventCommand.Post(args);

		this.TimerObject = window.setTimeout(this.Container + ".Update()", this.UpdateInterval);
	}
	
	this.Update = function()
	{
		this.CurrentTime += this.UpdateInterval;
		this.Debug("Update(), CurrentTime: " + this.CurrentTime);
		this.TimerObject = window.setTimeout(this.Container + ".Update()", this.UpdateInterval);
	}
	
	this.Stop = function()
	{
		this.Debug("Stop()");
		if (this.TimerObject != null)
		{
			window.clearTimeout(this.TimerObject);
		}
	}
	
	this.Debug = function(message)
	{
		SfDebug.DPF(this.m_debugLevel, "MockTimer: " + message);
	}
}


