// BEGINFILE SfSlider.js ----------------------------------------------------------------------------->

var SfSlider = Class.create(
{
	initialize: function(namePrefix, orientation)
	{
		this.NamePrefix = namePrefix;
		this.Orientation = orientation;
	},
	
	_debugLevel : SfDebug.Verbose,
// 	_debugLevel : SfDebug.Information,

	IsEnabled : true,
	
	_thumbLength : -1,
	_rangeMin : 0,
	_rangeMax : 100,
	_physicalMin : -1,
	_physicalMax : -1,
	_elementThumb : null,
	_elementGuide : null,
	
	_onMouseMoveDelegate : null,
	_onMouseUpDelegate : null,
	
	//Events
	ClickEvent : null,
	DragEvent : null,

	Debug : function(msg)
	{
		SfDebug.DPF(this._debugLevel, "SfSlider: " + msg);
	},
	
	OnLoad : function()
	{
		this.Debug("OnLoad()");
		this.Initialize();
	},
	
	OnUnLoad : function()
	{
		this.Debug("OnUnLoad()");
	},
	
	SetRange : function(min, max)
	{
		this._rangeMin = min;
		this._rangeMax = max;
	},
	
	GetRangeMin : function()
	{
		return this._rangeMin;
	},
	
	GetRangeMax : function()
	{
		return this._rangeMax;
	},
	
	SetPosition : function(position)
	{
		this.SetLogicalPosition(position);
	},
	
	Initialize : function()
	{
		this.Debug("Initialize()");

		this._elementThumb = SfDOM.FindElementFromID(document, this.NamePrefix + "_thumb");
		this._elementGuide =  SfDOM.FindElementFromID(document, this.NamePrefix + "_positionGuide");
		
		this._thumbLength = this.GetThumbLength();
		this._physicalMin = this.GetPhysicalMin();
		this._physicalMax = this._physicalMin + this.GetPhysicalLength();
		this.Debug("PhysicalMin: " + this._physicalMin);
		this.Debug("PhysicalMax: " + this._physicalMax);

		if (this.IsEnabled == true)
		{
			Event.observe(this._elementThumb, 'mousedown', this.BeginDrag.bindAsEventListener(this), true);
			Event.observe(this._elementGuide, 'click', this.GuideOnClick.bindAsEventListener(this), true);
			this._onMouseMoveDelegate = this.OnMove.bindAsEventListener(this);
			this._onMouseUpDelegate = this.OnUp.bindAsEventListener(this);
		
		}
		
		this.ClickEvent = new SfEvent("this.ClickEvent");
		this.DragEvent = new SfEvent("this.DragEvent");
	},
	
	GetThumbLength : function()
	{
		if (this.Orientation == SfSliderOrientation.Horizontal)
		{
			return this._elementThumb.offsetWidth;
		}
		else
		{
			return this._elementThumb.offsetHeight;
		}
	},
	
	GetPhysicalMin : function()
	{
		if (this.Orientation == SfSliderOrientation.Horizontal)
		{
			return this.GetPhysicalLeft();
		}
		else
		{
			return this.GetPhysicalTop();
		}
	},
	
	GetPhysicalLength : function()
	{
		if (this.Orientation == SfSliderOrientation.Horizontal)
		{
			return this._elementGuide.offsetWidth;
		}
		else
		{
			return this._elementGuide.offsetHeight;
		}
	},
	
	GetPhysicalLeft : function()
	{
		var physicalLeft = this._elementGuide.offsetLeft;
		var par = this._elementGuide.offsetParent;
		while (par)
		{
			this.Debug("parentOffset: " + par.offsetLeft);
			physicalLeft += par.offsetLeft;
			par = par.offsetParent;
		}
		return physicalLeft;
	},
	
	GetPhysicalTop : function()
	{
		var physicalTop = this._elementGuide.offsetTop;
		var par = this._elementGuide.offsetParent;
		while (par)
		{
			this.Debug("parentOffset: " + par.offsetTop);
			physicalTop += par.offsetTop;
			par = par.offsetParent;
		}
		return physicalTop;
	},

	LogicalToPhysical : function(logicalLength)
	{
		var physicalLength, totalLogicalLength, totalPhysicalLength;
		
		totalLogicalLength = this._rangeMax-this._rangeMin;
		totalPhysicalLength = this._physicalMax-this._physicalMin;
		
		if (totalLogicalLength==0)
		{
			physicalLength = 0;
		}
		else
		{
			physicalLength = (totalPhysicalLength) * logicalLength;
			physicalLength = physicalLength/(totalLogicalLength);
		}

		var physicalPosition;
		if (this.Orientation == SfSliderOrientation.Horizontal)
		{
			physicalPosition = this._physicalMin + physicalLength;
		}
		else
		{
			physicalPosition = this._physicalMax - physicalLength;
		}
		
		return physicalPosition;
	},
	
	PhysicalToLogical : function(physicalPosition)
	{
		var logicalLength, totalLogicalLength, totalPhysicalLength;
		
		totalLogicalLength = this._rangeMax-this._rangeMin;
		totalPhysicalLength = this._physicalMax-this._physicalMin;
		
		if (totalLogicalLength==0 || totalPhysicalLength==0)
		{
			logicalLength=0;
		}
		else if (physicalPosition < this._physicalMin)
		{
			if (this.Orientation == SfSliderOrientation.Horizontal)
			{
				logicalLength = 0;
			}
			else
			{
				logicalLength = totalLogicalLength;
			}
		}
		else if (physicalPosition > this._physicalMax)
		{
			if (this.Orientation == SfSliderOrientation.Horizontal)
			{
				logicalLength = totalLogicalLength;
			}
			else
			{
				logicalLength = 0;
			}
		}
		else
		{
			var physicalLength;
			if (this.Orientation == SfSliderOrientation.Horizontal)
			{
			    physicalLength = physicalPosition - this._physicalMin;
			}
			else
			{
				physicalLength = this._physicalMax - physicalPosition;
			}
			
			logicalLength = (totalLogicalLength) * physicalLength;
			logicalLength = logicalLength/(totalPhysicalLength);
		}
		
		return logicalLength;
	},
	
	SetPhysicalPosition : function(position)
	{
	    if (position < this._physicalMin)
	    {
			position = this._physicalMin;
		}
	    if (position > this._physicalMax)
	    {
			position = this._physicalMax;
		}
		
		if (this.Orientation == SfSliderOrientation.Horizontal)
		{
			this._elementThumb.style.left = position - this._physicalMin - this._thumbLength/2;
		}
		else
		{
			this._elementThumb.style.top = position - this._physicalMin - this._thumbLength/2;
		}
	},
	
	SetLogicalPosition : function(position)
	{
		if (position < this._rangeMin)
		{
			position = this._rangeMin;
		}
		if (position > this._rangeMax)
		{
			position = this._rangeMax;
		}
		
		this.SetPhysicalPosition(this.LogicalToPhysical(position));
	},
	
	GuideOnClick : function(evt)
	{
		evt = SfBrowserEvent.GetEvent(evt);
		this.PostClickEvent(this.GetLogicalPositionFromEvent(evt));
	},
	
	GetPhysicalPositionFromEvent : function(evt)
	{
		if (this.Orientation == SfSliderOrientation.Horizontal)
		{
			return evt.clientX;
		}
		else
		{
			return evt.clientY;
		}
	},
	
	GetLogicalPositionFromEvent : function(evt)
	{
		var physicalPos = this.GetPhysicalPositionFromEvent(evt);
		return this.PhysicalToLogical(physicalPos);
	},
	
	PostClickEvent : function(logicalPosition)
	{
		var args = new Object();
 		args.Position = logicalPosition;

		this.Debug("PostClickEvent(): " + args.Position);

		this.ClickEvent.Post(args);
	},
	
	PostDragEvent : function(type, logicalPosition)
	{
		var args = new Object();
		args.DragEventType = type;
 		args.Position = logicalPosition;
		
		this.Debug("PostDragEvent(), DragEventType :" + args.DragEventType + ", Position: " + args.Position);
		
		this.DragEvent.Post(args);
	},
	
	
	BeginDrag : function(evt)
	{
		this.Debug("BeginDrag()");
		
		Event.observe(document, 'mousemove', this._onMouseMoveDelegate, true);
		Event.observe(document, 'mouseup', this._onMouseUpDelegate, true);
		Event.stop(evt);

		this.PostDragEvent(SfSliderDragEventType.BeginDrag, this.GetLogicalPositionFromEvent(evt));
	},

	OnUp : function (evt)
	{
		var logicalPosition = this.GetLogicalPositionFromEvent(evt);

		this.Debug("OnUp(), logicalPosition: " + logicalPosition);

		Event.stopObserving(document, 'mousemove', this._onMouseMoveDelegate, true);
		Event.stopObserving(document, 'mouseup', this._onMouseUpDelegate, true);
		Event.stop(evt);
		
		this.PostDragEvent(SfSliderDragEventType.EndDrag, logicalPosition);
	},
		
	OnMove : function(evt)
	{
		var logicalPosition = this.GetLogicalPositionFromEvent(evt);

		this.Debug("OnMove(): position: " +  logicalPosition);
		
		Event.stop(evt);
		
		if (logicalPosition < this._rangeMin || logicalPosition > this._rangeMax)
		{
			return;
		}

		this.PostDragEvent(SfSliderDragEventType.DragMove, logicalPosition);
	}
}
);

// ENDFILE SfSlider.js ------------------------------------------------------------------------------->

var SfDiscreteSlider = Class.create(SfSlider,
{
	initialize: function($super, namePrefix, orientation, numPoints)
	{
		$super(namePrefix, orientation);
		this._numPoints = numPoints;

		this.DivideIntoPoints();
	},
	
	_points : null,
	
	SetPointNumber : function(pointNumber)
	{
		this.Debug("SetPointNumber(): " + pointNumber);
		this.SetPosition(this._points[pointNumber]);
	},
	
	FindClosestPointNumber : function(pos)
	{
		this.Debug("FindClosestPointNumber(): " + pos);
		var closestPoint = 0;
		var minDistance = Math.abs(this._points[0] - pos);
		for (var i=1; i<this._points.length; ++i)
		{
			var distance = Math.abs(this._points[i] - pos);
			if (distance < minDistance)
			{
				minDistance = distance;
				closestPoint = i;
			}
		}
		
		return closestPoint;
	},

	DivideIntoPoints : function()
	{
		this.Debug("DivideIntoPoints()");

		var min = this.GetRangeMin();
		var max = this.GetRangeMax();
		
		var length = max - min;
		var numSegments = this._numPoints - 1;
		var segmentLength = length / numSegments;
		
		this._points = new Array(this._numPoints);
		
		this._points[0] = min;
		for (var i=1; i<=numSegments; ++i)
		{
			this._points[i] = min + i*segmentLength;
		}
		
		this.Debug("min: " + min + ", max: " + max);
	}
}
);